package com.qmth.distributed.print.business.service;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.service.IService;
import com.qmth.distributed.print.business.bean.result.DictionaryResult;
import com.qmth.distributed.print.business.bean.result.TeachCourseResult;
import com.qmth.distributed.print.business.entity.TeachCourse;
import com.qmth.teachcloud.common.entity.SysUser;

import java.util.List;

/**
 * @Description: 教学课程服务类
 * @Author: CaoZixuan
 * @Date: 2022-02-07
 */
public interface TeachCourseService extends IService<TeachCourse> {


    /**
     * 分页查询教学课程列表
     *
     * @param courseName 课程名称
     * @param pageNumber 分页参数
     * @param pageSize   分页容量
     * @param userId     用户id
     * @return 教学课程分页结果
     */
    IPage<TeachCourseResult> teachCoursePage(String courseName, int pageNumber, int pageSize, Long userId);

    /**
     * 创建教学课程
     *
     * @param basicCourseId 基础课程id
     * @param requestUser   请求的用户
     * @return 创建结果
     */
    Boolean createTeachCourse(Long basicCourseId, SysUser requestUser);

    /**
     * 根据用户id查询该用户所属机构下可以创建为教学课程的基础课程列表
     *
     * @param requestUser 请求的用户
     * @return 课程列表
     */
    List<DictionaryResult> findBasicCourseByUser(SysUser requestUser);

    /**
     * 根据教学课程id集合批量删除教学课程
     *
     * @param idList 教学课程idList
     * @return 删除结果
     */
    Boolean deleteTeachCourseBatch(List<Long> idList);

}
