package com.qmth.teachcloud.common.service.impl;

import com.aliyuncs.DefaultAcsClient;
import com.aliyuncs.IAcsClient;
import com.aliyuncs.dysmsapi.model.v20170525.SendSmsRequest;
import com.aliyuncs.dysmsapi.model.v20170525.SendSmsResponse;
import com.aliyuncs.exceptions.ClientException;
import com.aliyuncs.http.MethodType;
import com.aliyuncs.profile.DefaultProfile;
import com.aliyuncs.profile.IClientProfile;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.qmth.teachcloud.common.config.DictionaryConfig;
import com.qmth.teachcloud.common.entity.BasicVerifyCode;
import com.qmth.teachcloud.common.entity.SysConfig;
import com.qmth.teachcloud.common.entity.SysUser;
import com.qmth.teachcloud.common.enums.ExceptionResultEnum;
import com.qmth.teachcloud.common.mapper.BasicVerifyCodeMapper;
import com.qmth.teachcloud.common.service.BasicVerifyCodeService;
import com.qmth.teachcloud.common.service.SysConfigService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.Calendar;
import java.util.Date;

/**
 * <p>
 * 短信验证码记录表 服务实现类
 * </p>
 *
 * @author xf
 * @since 2021-03-23
 */
@Service
public class BasicVerifyCodeServiceImpl extends ServiceImpl<BasicVerifyCodeMapper, BasicVerifyCode> implements BasicVerifyCodeService {

    @Autowired
    private DictionaryConfig dictionaryConfig;

    @Autowired
    private SysConfigService sysConfigService;

    @Override
    public void sendVeirfyCode(String mobileNumber, SysUser sysUser) {
        SysConfig sysConfig = sysConfigService.getByKey("sys.code.enable");
        if (sysConfig.getConfigValue() == null) {
            throw ExceptionResultEnum.ERROR.exception("短信验证码启用开关未设置");
        }
        if (sysConfig.getConfigValue().equals("false")) {
            throw ExceptionResultEnum.ERROR.exception("短信验证码已关闭");
        }
        QueryWrapper<BasicVerifyCode> wrapper = new QueryWrapper<>();
        wrapper.lambda().eq(BasicVerifyCode::getMobileNumber, mobileNumber).eq(BasicVerifyCode::getUserId, sysUser.getId());
        BasicVerifyCode basicVerifyCode = this.getOne(wrapper);
        if (basicVerifyCode != null) {
            Date oldCreateTime = new Date(basicVerifyCode.getCreateTime());
            Integer sendInterval = dictionaryConfig.smsDomain().getCodeSendInterval();
            if ((System.currentTimeMillis() - oldCreateTime.getTime()) < sendInterval * 1000) {
                throw ExceptionResultEnum.ERROR.exception("发送验证码过于频繁，请" + sendInterval + "秒之后再试");
            }
        }
        try {
            StringBuilder sb = new StringBuilder();
            sb.append((int) ((Math.random() * 9 + 1) * 1000));
            String verifyCode = sb.toString();
            System.setProperty("sun.net.client.defaultConnectTimeout", "180000");
            System.setProperty("sun.net.client.defaultReadTimeout", "18000");
            // 初始化ascClient需要的几个参数
            final String product = "Dysmsapi";// 短信API产品名称（短信产品名固定，无需修改）
            final String domain = "dysmsapi.aliyuncs.com";// 短信API产品域名（接口地址固定，无需修改）
            // 替换成你的AK
            final String accessKeyId = dictionaryConfig.smsDomain().getAliyunSMSKey();// 你的accessKeyId,参考本文档步骤2
            final String accessKeySecret = dictionaryConfig.smsDomain().getAliyunSMSSecret();// 你的accessKeySecret，参考本文档步骤2
            // 初始化ascClient,暂时不支持多region（请勿修改）
            IClientProfile profile = DefaultProfile.getProfile("cn-hangzhou", accessKeyId, accessKeySecret);
            DefaultProfile.addEndpoint("cn-hangzhou", "cn-hangzhou", product, domain);
            IAcsClient acsClient = new DefaultAcsClient(profile);
            // 组装请求对象
            SendSmsRequest request = new SendSmsRequest();
            // 使用post提交
            request.setMethod(MethodType.POST);
            // 必填:待发送手机号。支持以逗号分隔的形式进行批量调用，批量上限为1000个手机号码,批量调用相对于单条调用及时性稍有延迟,验证码类型的短信推荐使用单条调用的方式；发送国际/港澳台消息时，接收号码格式为00+国际区号+号码，如“0085200000000”
            request.setPhoneNumbers(mobileNumber);
            // 必填:短信签名-可在短信控制台中找到
            request.setSignName(dictionaryConfig.smsDomain().getAliyunSMSSignName());
            // 必填:短信模板-可在短信控制台中找到
            request.setTemplateCode(dictionaryConfig.smsDomain().getAliyunSMSTplCode());
            // 可选:模板中的变量替换JSON串,如模板内容为"亲爱的${name},您的验证码为${code}"时,此处的值为
            // 友情提示:如果JSON中需要带换行符,请参照标准的JSON协议对换行符的要求,比如短信内容中包含\r\n的情况在JSON中需要表示成\\r\\n,否则会导致JSON在服务端解析失败
            request.setTemplateParam("{\"code\":\"" + verifyCode + "\"}");
            // 可选-上行短信扩展码(扩展码字段控制在7位或以下，无特殊需求用户请忽略此字段)
            // request.setSmsUpExtendCode("90997");
            // 可选:outId为提供给业务方扩展字段,最终在短信回执消息中将此值带回给调用者
            // request.setOutId("yourOutId");
            // 请求失败这里会抛ClientException异常
            SendSmsResponse sendSmsResponse = acsClient.getAcsResponse(request);
            if (sendSmsResponse.getCode() != null && sendSmsResponse.getCode().equals("OK")) {
                // 请求成功
                Integer codeExpiredTime = dictionaryConfig.smsDomain().getCodeExpiredTime();
                if (basicVerifyCode == null) {
                    basicVerifyCode = new BasicVerifyCode();
                    basicVerifyCode.setUserId(sysUser.getId());
                    basicVerifyCode.setSchoolId(sysUser.getSchoolId());
                    basicVerifyCode.setMobileNumber(mobileNumber);
                    basicVerifyCode.setExpireTime(processMiniute(new Date(), codeExpiredTime));
                    basicVerifyCode.setValidPeriod(codeExpiredTime);
                    basicVerifyCode.setVerifyCode(verifyCode);
                    basicVerifyCode.setCreateId(sysUser.getId());
                    basicVerifyCode.setCreateTime(System.currentTimeMillis());
                    this.save(basicVerifyCode);
                } else {
                    basicVerifyCode.setExpireTime(processMiniute(new Date(), codeExpiredTime));
                    basicVerifyCode.setValidPeriod(codeExpiredTime);
                    basicVerifyCode.setVerifyCode(verifyCode);
                    basicVerifyCode.setUpdateId(sysUser.getId());
                    basicVerifyCode.setUpdateTime(System.currentTimeMillis());
                    this.updateById(basicVerifyCode);
                }
            } else {
                if("isv.MOBILE_NUMBER_ILLEGAL".equals(sendSmsResponse.getCode())){
                    throw ExceptionResultEnum.ERROR.exception("非法手机号");
                }else {
                    throw ExceptionResultEnum.ERROR.exception(sendSmsResponse.getMessage());
                }
            }
        } catch (ClientException e) {
            String error = e.getMessage();
            throw ExceptionResultEnum.ERROR.exception("请重新获取验证码");
        }
    }

    private static Long processMiniute(Date oldTime, int m) {
        Calendar calendar = Calendar.getInstance();
        calendar.setTime(oldTime);
        calendar.add(Calendar.MINUTE, m);
        return calendar.getTime().getTime();
    }
}
