SET NAMES UTF8;

-- ----------------------------
-- Table structure for basic_attachment
-- ----------------------------
DROP TABLE IF EXISTS `basic_attachment`;
CREATE TABLE `basic_attachment` (
                                    `id` bigint NOT NULL,
                                    `name` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '文件名',
                                    `type` varchar(10) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '文件类型',
                                    `size` int NOT NULL COMMENT '单位（KB）',
                                    `md5` varchar(32) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '文件md5值',
                                    `path` varchar(2000) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '存储路径',
                                    `create_id` bigint DEFAULT NULL COMMENT '创建人',
                                    `create_time` bigint DEFAULT NULL COMMENT '创建时间',
                                    `obj_id` bigint DEFAULT NULL COMMENT '关联业务id',
                                    PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 ROW_FORMAT=DYNAMIC COMMENT='所有附件记录表';

-- ----------------------------
-- Table structure for basic_campus
-- ----------------------------
DROP TABLE IF EXISTS `basic_campus`;
CREATE TABLE `basic_campus` (
                                `id` bigint NOT NULL COMMENT '校区id',
                                `school_id` bigint NOT NULL COMMENT '学校id',
                                `campus_name` varchar(64) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '校区名称',
                                `campus_code` varchar(64) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '校区编码',
                                `print_house_id` bigint DEFAULT NULL COMMENT '印刷室id',
                                `enable` tinyint DEFAULT '1' COMMENT '是否可用',
                                `org_id` bigint DEFAULT NULL COMMENT '机构id',
                                `create_id` bigint DEFAULT NULL COMMENT '创建人id',
                                `create_time` bigint DEFAULT NULL COMMENT '创建时间',
                                `update_id` bigint DEFAULT NULL COMMENT '更新人id',
                                `update_time` bigint DEFAULT NULL COMMENT '更新时间',
                                PRIMARY KEY (`id`),
                                UNIQUE KEY `campus_schoolId_code_idx` (`school_id`,`campus_code`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='基础校区表';

-- ----------------------------
-- Table structure for basic_course
-- ----------------------------
DROP TABLE IF EXISTS `basic_course`;
CREATE TABLE `basic_course` (
                                `id` bigint NOT NULL COMMENT '课程主键',
                                `school_id` bigint NOT NULL COMMENT '学校id',
                                `code` varchar(100) DEFAULT NULL COMMENT '课程编号',
                                `name` varchar(100) DEFAULT NULL COMMENT '课程名称',
                                `create_id` bigint DEFAULT NULL,
                                `create_time` bigint DEFAULT NULL,
                                `update_id` bigint DEFAULT NULL,
                                `update_time` bigint DEFAULT NULL,
                                `historic_name` varchar(100) DEFAULT NULL COMMENT '历史课程名称',
                                `org_id` bigint DEFAULT NULL COMMENT '机构id',
                                `teaching_room_id` bigint DEFAULT NULL COMMENT '教研室id',
                                `enable` tinyint DEFAULT NULL,
                                `short_code` varchar(10) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '简码',
                                PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 ROW_FORMAT=DYNAMIC COMMENT='课程基础表';

-- ----------------------------
-- Table structure for basic_school
-- ----------------------------
DROP TABLE IF EXISTS `basic_school`;
CREATE TABLE `basic_school` (
                                `id` bigint NOT NULL,
                                `code` varchar(100) DEFAULT NULL COMMENT '学校编号',
                                `name` varchar(100) DEFAULT NULL COMMENT '学校名称',
                                `enable` tinyint DEFAULT '1' COMMENT '是否启用，false：停用，true：启用',
                                `access_key` varchar(64) DEFAULT NULL COMMENT '访问key',
                                `access_secret` varchar(64) DEFAULT NULL COMMENT '访问secret',
                                `remark` text COMMENT '备注',
                                `logo` varchar(64) DEFAULT NULL COMMENT 'logo',
                                `create_id` bigint DEFAULT NULL COMMENT '创建人',
                                `create_time` bigint DEFAULT NULL COMMENT '创建时间',
                                `update_time` bigint DEFAULT NULL COMMENT '更新时间',
                                `update_id` bigint DEFAULT NULL COMMENT '更新人',
                                PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 ROW_FORMAT=DYNAMIC COMMENT='学校基础表';

-- ----------------------------
-- Table structure for basic_semester
-- ----------------------------
DROP TABLE IF EXISTS `basic_semester`;
CREATE TABLE `basic_semester` (
                                  `id` bigint NOT NULL COMMENT '主键',
                                  `school_id` bigint NOT NULL COMMENT '学校id',
                                  `name` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '学期名称',
                                  `code` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '学期编码',
                                  `start_time` bigint DEFAULT NULL COMMENT '开始日期',
                                  `end_time` bigint DEFAULT NULL COMMENT '结束日期',
                                  `org_id` bigint DEFAULT NULL COMMENT '机构id',
                                  `enable` tinyint DEFAULT '1' COMMENT '是否启用，0：停用，1：启用',
                                  `create_id` bigint DEFAULT NULL COMMENT '创建人id',
                                  `create_time` bigint DEFAULT NULL COMMENT '创建时间',
                                  `update_id` bigint DEFAULT NULL COMMENT '更新人id',
                                  `update_time` bigint DEFAULT NULL COMMENT '更新时间',
                                  `in_used` tinyint(1) DEFAULT NULL COMMENT '是否当前使用学期',
                                  PRIMARY KEY (`id`) USING BTREE,
                                  UNIQUE KEY `semester_schoolId_name_idx` (`school_id`,`name`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='学期字典表';

-- ----------------------------
-- Table structure for basic_user_course
-- ----------------------------
DROP TABLE IF EXISTS `basic_user_course`;
CREATE TABLE `basic_user_course` (
                                     `id` bigint NOT NULL,
                                     `user_id` bigint DEFAULT NULL COMMENT '用户ID',
                                     `course_id` bigint DEFAULT NULL COMMENT '课程ID',
                                     `create_id` bigint DEFAULT NULL,
                                     `create_time` bigint DEFAULT NULL,
                                     `update_id` bigint DEFAULT NULL,
                                     `update_time` bigint DEFAULT NULL,
                                     PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 ROW_FORMAT=DYNAMIC COMMENT='用户和课程关联表';

-- ----------------------------
-- Table structure for basic_verify_code
-- ----------------------------
DROP TABLE IF EXISTS `basic_verify_code`;
CREATE TABLE `basic_verify_code` (
                                     `id` bigint NOT NULL,
                                     `user_id` bigint NOT NULL COMMENT '用户ID',
                                     `mobile_number` varchar(11) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '手机号',
                                     `expire_time` bigint NOT NULL COMMENT '到期时间',
                                     `valid_period` int NOT NULL COMMENT '单位（分）',
                                     `verify_code` varchar(4) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '4位数字',
                                     `create_id` bigint DEFAULT NULL,
                                     `create_time` bigint DEFAULT NULL,
                                     `update_id` bigint DEFAULT NULL,
                                     `update_time` bigint DEFAULT NULL,
                                     `school_id` bigint DEFAULT NULL COMMENT '学校id',
                                     `org_id` bigint DEFAULT NULL COMMENT '机构id',
                                     PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 ROW_FORMAT=DYNAMIC COMMENT='短信验证码记录表';

-- ----------------------------
-- Table structure for grade_batch_student
-- ----------------------------
DROP TABLE IF EXISTS `grade_batch_student`;
CREATE TABLE `grade_batch_student` (
                                       `id` bigint NOT NULL,
                                       `batch_id` bigint DEFAULT NULL COMMENT '分析-批次表ID',
                                       `course_code` varchar(50) DEFAULT NULL COMMENT '课程编码',
                                       `course_name` varchar(100) DEFAULT NULL COMMENT '课程名称',
                                       `paper_number` varchar(50) DEFAULT NULL COMMENT '试卷编号',
                                       `paper_type` varchar(16) DEFAULT NULL COMMENT '试卷类型',
                                       `student_code` varchar(45) DEFAULT NULL COMMENT '学号',
                                       `student_name` varchar(100) DEFAULT NULL COMMENT '学生姓名',
                                       `ticket_number` varchar(45) DEFAULT NULL COMMENT '准考证号',
                                       `teacher_name` varchar(100) DEFAULT NULL COMMENT '任课老师',
                                       `teacher_number` varchar(45) DEFAULT NULL COMMENT '任课老师工号',
                                       `create_id` bigint DEFAULT NULL,
                                       `create_time` bigint DEFAULT NULL,
                                       `update_id` bigint DEFAULT NULL,
                                       `update_time` bigint DEFAULT NULL,
                                       PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='考务数据（包含任课老师）';

-- ----------------------------
-- Table structure for sys_config
-- ----------------------------
DROP TABLE IF EXISTS `sys_config`;
CREATE TABLE `sys_config` (
                              `id` bigint NOT NULL,
                              `school_id` bigint DEFAULT NULL COMMENT '学校id',
                              `org_id` bigint DEFAULT NULL COMMENT '机构id',
                              `config_key` varchar(100) NOT NULL COMMENT '参数键名',
                              `config_name` varchar(100) NOT NULL COMMENT '参数名称',
                              `config_value` varchar(100) NOT NULL COMMENT '参数键值',
                              `remark` varchar(100) DEFAULT NULL,
                              `create_id` bigint DEFAULT NULL,
                              `create_time` bigint DEFAULT NULL,
                              `update_id` bigint DEFAULT NULL,
                              `update_time` bigint DEFAULT NULL,
                              PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 ROW_FORMAT=DYNAMIC COMMENT='参数表';

-- ----------------------------
-- Table structure for sys_org
-- ----------------------------
DROP TABLE IF EXISTS `sys_org`;
CREATE TABLE `sys_org` (
                           `id` bigint NOT NULL,
                           `school_id` bigint NOT NULL COMMENT '学校ID',
                           `type` varchar(50) NOT NULL DEFAULT 'COLLEGE' COMMENT '类型，SCHOOL：学校，COLLEGE：学院，FACULTY：院系，TEACHING_ROOM：教研室，PRINTING_HOUSE：印刷厂',
                           `code` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '机构代码',
                           `name` varchar(100) NOT NULL COMMENT '机构名称',
                           `parent_id` bigint DEFAULT NULL COMMENT '上级机构ID',
                           `enable` tinyint NOT NULL DEFAULT '1' COMMENT '是否启用，false：停用，true：启用',
                           `create_id` bigint DEFAULT NULL COMMENT '创建人',
                           `create_time` bigint DEFAULT NULL COMMENT '创建时间',
                           `update_id` bigint DEFAULT NULL COMMENT '修改人',
                           `update_time` bigint DEFAULT NULL COMMENT '修改时间',
                           `historic_name` varchar(100) DEFAULT NULL COMMENT '历史机构名称',
                           PRIMARY KEY (`id`) USING BTREE,
                           UNIQUE KEY `org_schoolId_code_idx` (`school_id`,`code`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 ROW_FORMAT=DYNAMIC COMMENT='学校组织架构';

-- ----------------------------
-- Table structure for sys_privilege
-- ----------------------------
DROP TABLE IF EXISTS `sys_privilege`;
CREATE TABLE `sys_privilege` (
                                 `id` bigint NOT NULL,
                                 `name` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '菜单名称',
                                 `url` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT 'URL地址',
                                 `type` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '类型，MENU：菜单，BUTTON：按钮，LINK：链接，URL：接口地址，LIST：列表，CONDITION：查询条件',
                                 `parent_id` bigint DEFAULT NULL COMMENT '上级菜单',
                                 `sequence` int NOT NULL COMMENT '序号',
                                 `property` varchar(30) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '属性，NO_AUTH：无需鉴权，AUTH：鉴权，SYS：系统公用',
                                 `related` text CHARACTER SET utf8 COLLATE utf8_general_ci COMMENT '关联属性，type为URL且property为AUTH才有',
                                 `enable` tinyint NOT NULL DEFAULT '1' COMMENT '是否启用，0：停用，1：启用',
                                 `default_auth` tinyint DEFAULT '1' COMMENT '默认权限，0：否，1：是',
                                 `front_display` tinyint DEFAULT '1' COMMENT '是否前端展示',
                                 PRIMARY KEY (`id`) USING BTREE,
                                 UNIQUE KEY `privilege_index` (`name`,`url`,`type`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='菜单权限表';

-- ----------------------------
-- Table structure for sys_role
-- ----------------------------
DROP TABLE IF EXISTS `sys_role`;
CREATE TABLE `sys_role` (
                            `id` bigint NOT NULL,
                            `school_id` bigint DEFAULT NULL COMMENT '学校ID',
                            `name` varchar(50) NOT NULL COMMENT '角色名称',
                            `enable` tinyint NOT NULL DEFAULT '1' COMMENT '是否启用，false：停用，true：启用',
                            `type` varchar(20) DEFAULT NULL COMMENT '角色类别，ADMIN：超级管理员，SCHOOL_ADMIN：管理员：EXAM_TEACHER：考务老师，QUESTION_TEACHER：命题老师，CUSTOMER：客服人员，PRINTER：印刷人员，CUSTOM：自定义',
                            `create_id` bigint DEFAULT NULL COMMENT '创建人',
                            `create_time` bigint DEFAULT NULL COMMENT '创建时间',
                            `update_id` bigint DEFAULT NULL COMMENT '修改人',
                            `update_time` bigint DEFAULT NULL COMMENT '修改时间',
                            `default_role` tinyint NOT NULL DEFAULT '0' COMMENT '是否系统内置角色，1：是，0：不是',
                            `org_id` bigint DEFAULT NULL COMMENT '机构id',
                            `source` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '角色来源，ANALYSIS：教研分析',
                            `interpret` varchar(1000) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '角色说明',
                            PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 ROW_FORMAT=DYNAMIC COMMENT='角色表';

-- ----------------------------
-- Table structure for sys_role_privilege
-- ----------------------------
DROP TABLE IF EXISTS `sys_role_privilege`;
CREATE TABLE `sys_role_privilege` (
                                      `id` bigint NOT NULL AUTO_INCREMENT,
                                      `role_id` bigint NOT NULL COMMENT '角色ID',
                                      `privilege_id` bigint NOT NULL COMMENT '菜单ID',
                                      `enable` tinyint DEFAULT '1' COMMENT '是否禁用，false：禁用，true：启用',
                                      PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB AUTO_INCREMENT=1535069410968068099 DEFAULT CHARSET=utf8 ROW_FORMAT=DYNAMIC COMMENT='角色和菜单关联表';

-- ----------------------------
-- Table structure for sys_user
-- ----------------------------
DROP TABLE IF EXISTS `sys_user`;
CREATE TABLE `sys_user` (
                            `id` bigint NOT NULL,
                            `school_id` bigint DEFAULT NULL COMMENT '学校ID',
                            `login_name` varchar(100) NOT NULL COMMENT '用户名',
                            `real_name` varchar(100) NOT NULL COMMENT '姓名',
                            `password` varchar(50) NOT NULL COMMENT '密码',
                            `mobile_number` varchar(30) DEFAULT NULL COMMENT '手机号',
                            `org_id` bigint DEFAULT NULL,
                            `enable` tinyint NOT NULL DEFAULT '1' COMMENT 'false-禁用，true-启用',
                            `pwd_update_time` bigint DEFAULT NULL COMMENT '密码修改时间',
                            `remark` varchar(200) DEFAULT NULL COMMENT '备注',
                            `create_id` bigint DEFAULT NULL COMMENT '创建人',
                            `create_time` bigint DEFAULT NULL COMMENT '创建时间',
                            `update_id` bigint DEFAULT NULL,
                            `update_time` bigint DEFAULT NULL,
                            `code` varchar(100) DEFAULT NULL COMMENT '工号',
                            `pwd_count` tinyint DEFAULT '0' COMMENT '密码修改次数，默认为0',
                            `sync_status` varchar(100) DEFAULT NULL COMMENT '同步状态，NEED_PUSH_AGAIN("需要重新推送"),',
                            `historic_name` varchar(100) DEFAULT NULL COMMENT '历史用户名称',
                            PRIMARY KEY (`id`) USING BTREE,
                            UNIQUE KEY `user_schoolId_loginName_idx` (`school_id`,`login_name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 ROW_FORMAT=DYNAMIC COMMENT='用户表';

-- ----------------------------
-- Table structure for sys_user_role
-- ----------------------------
DROP TABLE IF EXISTS `sys_user_role`;
CREATE TABLE `sys_user_role` (
                                 `id` bigint NOT NULL AUTO_INCREMENT,
                                 `user_id` bigint NOT NULL COMMENT '用户ID',
                                 `role_id` bigint NOT NULL COMMENT '角色ID',
                                 `privilege_id` bigint DEFAULT NULL COMMENT '权限id',
                                 `enable` tinyint NOT NULL DEFAULT '1' COMMENT '是否禁用，false：禁用，true：启用',
                                 PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB AUTO_INCREMENT=1417682390898266121 DEFAULT CHARSET=utf8 ROW_FORMAT=DYNAMIC COMMENT='用户和角色关联表';

-- ----------------------------
-- Table structure for t_a_exam_course
-- ----------------------------
DROP TABLE IF EXISTS `t_a_exam_course`;
CREATE TABLE `t_a_exam_course` (
                                   `id` bigint NOT NULL COMMENT '考试科目分析表id',
                                   `exam_id` bigint NOT NULL COMMENT '考试id',
                                   `exam_name` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '考试名称（冗余）',
                                   `course_code` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '科目编码',
                                   `course_name` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '科目名称',
                                   `school_id` bigint NOT NULL COMMENT '学校id（冗余）',
                                   `teach_college_id` bigint DEFAULT NULL COMMENT '开课学院id',
                                   `teach_college_name` varchar(64) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '开课学院名称',
                                   `inspect_college_count` int DEFAULT NULL COMMENT '考察学院数量',
                                   `inspect_college_names` text CHARACTER SET utf8 COLLATE utf8_general_ci COMMENT '考察学院名称',
                                   `avg_score` decimal(12,4) DEFAULT NULL COMMENT '总体平均分',
                                   `pass_count` int DEFAULT NULL COMMENT '通过人数',
                                   `pass_rate` decimal(12,4) DEFAULT NULL COMMENT '通过率',
                                   `current_pass_count` int DEFAULT NULL COMMENT '应届通过人数',
                                   `current_pass_rate` decimal(12,4) DEFAULT NULL COMMENT '应届通过率',
                                   `total_score` decimal(12,4) DEFAULT NULL COMMENT '试卷满分',
                                   `reality_count` int DEFAULT NULL COMMENT '实际参考人数',
                                   `absent_count` int DEFAULT NULL COMMENT '缺考人数',
                                   `total_count` int DEFAULT NULL COMMENT '总应参考人数',
                                   `current_min_score` decimal(12,4) DEFAULT NULL COMMENT '最低分',
                                   `current_max_score` decimal(12,4) DEFAULT NULL COMMENT '最高分',
                                   `current_avg_score` decimal(12,4) DEFAULT NULL COMMENT '全体参考平均分',
                                   `current_reality_count` int DEFAULT NULL COMMENT '应届实际考试人数',
                                   `current_absent_count` int DEFAULT NULL COMMENT '应届缺考人数',
                                   `current_total_count` int DEFAULT NULL COMMENT '应届总考试人数',
                                   `current_reality_rate` decimal(12,4) DEFAULT NULL COMMENT '应届实际考试人数占比',
                                   `past_reality_count` int DEFAULT NULL COMMENT '往届实际考试人数',
                                   `past_absent_count` int DEFAULT NULL COMMENT '往届缺考人数',
                                   `past_total_count` int DEFAULT NULL COMMENT '往届总人数',
                                   `past_reality_rate` decimal(12,4) DEFAULT NULL COMMENT '往届实际考试人数占比',
                                   `current_upper_quartile` decimal(12,4) DEFAULT NULL COMMENT '上四分位数',
                                   `current_median` decimal(12,4) DEFAULT NULL COMMENT '中位数',
                                   `current_lower_quartile` decimal(12,4) DEFAULT NULL COMMENT '下四分位数',
                                   `current_mode` varchar(64) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '众数',
                                   `current_standard_deviation` decimal(12,4) DEFAULT NULL COMMENT '标准差',
                                   `current_score_rate` decimal(12,4) DEFAULT NULL COMMENT '难度系数（得分率）',
                                   `difficulty` varchar(16) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '本次科目难度（应届）',
                                   `paper_avg_score` decimal(12,4) DEFAULT NULL COMMENT '总体卷面平均分',
                                   `paper_current_avg_score` decimal(12,4) DEFAULT NULL COMMENT '应届卷面平均分',
                                   `paper_pass_rate` decimal(12,4) DEFAULT NULL COMMENT '总体卷面成绩通过率',
                                   `paper_current_pass_rate` decimal(12,4) DEFAULT NULL COMMENT '应届卷面成绩通过率',
                                   `paper_pass_count` int DEFAULT NULL COMMENT '卷面总体通过人数',
                                   `paper_current_pass_count` int DEFAULT NULL COMMENT '卷面应届通过人数',
                                   `coefficient` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '赋分系数',
                                   PRIMARY KEY (`id`) USING BTREE,
                                   KEY `t_a_exam_course_idx` (`exam_id`,`course_code`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 ROW_FORMAT=DYNAMIC COMMENT='考试课程维度分析表';

-- ----------------------------
-- Table structure for t_a_exam_course_clazz
-- ----------------------------
DROP TABLE IF EXISTS `t_a_exam_course_clazz`;
CREATE TABLE `t_a_exam_course_clazz` (
                                         `id` bigint NOT NULL COMMENT 'id',
                                         `exam_id` bigint NOT NULL COMMENT '考试id',
                                         `school_id` bigint DEFAULT NULL,
                                         `course_code` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '科目编码',
                                         `course_name` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '科目名称',
                                         `clazz_id` bigint NOT NULL COMMENT '班级表id',
                                         `max_score` decimal(12,4) DEFAULT NULL COMMENT '最高分（赋分）',
                                         `min_score` decimal(12,4) DEFAULT NULL COMMENT '最低分（赋分）',
                                         `avg_score` decimal(12,4) DEFAULT NULL COMMENT '平均分（赋分）',
                                         `reality_count` int DEFAULT NULL COMMENT '实际参考人数',
                                         `absent_count` int DEFAULT NULL COMMENT '缺考人数',
                                         `total_count` int DEFAULT NULL COMMENT '总人数',
                                         `college_name` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '所属考察学院名称',
                                         PRIMARY KEY (`id`) USING BTREE,
                                         KEY `t_a_exam_course_clazz_idx` (`exam_id`,`course_code`,`clazz_id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 ROW_FORMAT=DYNAMIC COMMENT='参考课程班级维度分析表';

-- ----------------------------
-- Table structure for t_a_exam_course_college_inspect
-- ----------------------------
DROP TABLE IF EXISTS `t_a_exam_course_college_inspect`;
CREATE TABLE `t_a_exam_course_college_inspect` (
                                                   `id` bigint NOT NULL,
                                                   `exam_id` bigint NOT NULL COMMENT '考试id',
                                                   `school_id` bigint DEFAULT NULL,
                                                   `course_code` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '科目编码',
                                                   `course_name` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '科目名称',
                                                   `college_id` bigint NOT NULL COMMENT '学院id',
                                                   `max_score` decimal(12,4) DEFAULT NULL COMMENT '最高分',
                                                   `min_score` decimal(12,4) DEFAULT NULL COMMENT '最低分',
                                                   `avg_score` decimal(12,4) DEFAULT NULL COMMENT '平均分',
                                                   `reality_count` int DEFAULT NULL COMMENT '实际参考人数',
                                                   `absent_count` int DEFAULT NULL COMMENT '缺考人数',
                                                   `total_count` int DEFAULT NULL COMMENT '总人数',
                                                   `upper_quartile` decimal(12,4) DEFAULT NULL COMMENT '上四分位数',
                                                   `median` decimal(12,4) DEFAULT NULL COMMENT '中位数',
                                                   `lower_quartile` decimal(12,4) DEFAULT NULL COMMENT '下四分位数',
                                                   `mode` varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '众数',
                                                   `standard_deviation` decimal(12,4) DEFAULT NULL COMMENT '标准差',
                                                   `relative_position` decimal(12,4) DEFAULT NULL COMMENT '相对位置',
                                                   PRIMARY KEY (`id`) USING BTREE,
                                                   KEY `t_a_exam_course_college_idx` (`exam_id`,`course_code`,`college_id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 ROW_FORMAT=DYNAMIC COMMENT='参考课程考察学院维度分析表';

-- ----------------------------
-- Table structure for t_a_exam_course_college_inspect_dio
-- ----------------------------
DROP TABLE IF EXISTS `t_a_exam_course_college_inspect_dio`;
CREATE TABLE `t_a_exam_course_college_inspect_dio` (
                                                       `id` bigint NOT NULL COMMENT 'id',
                                                       `exam_id` bigint NOT NULL COMMENT '考试id',
                                                       `school_id` bigint DEFAULT NULL,
                                                       `course_code` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '科目编码',
                                                       `course_name` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '科目名称',
                                                       `inspect_college_id` bigint NOT NULL COMMENT '考察学院id',
                                                       `inspect_college_name` varchar(32) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '考察学院名称',
                                                       `dimension_type` varchar(32) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '模块类型',
                                                       `dimension_code` varchar(32) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '考察点编号',
                                                       `avg_score` decimal(12,4) DEFAULT NULL COMMENT '考察点学院学生平均得分',
                                                       `score_rate` decimal(12,4) DEFAULT NULL COMMENT '该考察点学院平均得分率',
                                                       PRIMARY KEY (`id`) USING BTREE,
                                                       KEY `t_a_exam_course_college_inspect_dio_idx` (`school_id`,`exam_id`,`course_code`,`dimension_type`,`dimension_code`,`inspect_college_id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 ROW_FORMAT=DYNAMIC COMMENT='参考课程考察学院各考察点维度表';

-- ----------------------------
-- Table structure for t_a_exam_course_college_paper_struct
-- ----------------------------
DROP TABLE IF EXISTS `t_a_exam_course_college_paper_struct`;
CREATE TABLE `t_a_exam_course_college_paper_struct` (
                                                        `id` bigint NOT NULL COMMENT '主键',
                                                        `school_id` bigint NOT NULL COMMENT '学校id',
                                                        `paper_struct_id` bigint NOT NULL COMMENT '试卷结构基础表id',
                                                        `exam_id` bigint NOT NULL COMMENT '考试id',
                                                        `course_code` varchar(32) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '课程编号',
                                                        `course_name` varchar(32) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '课程名称',
                                                        `paper_id` bigint NOT NULL COMMENT '试卷id',
                                                        `inspect_college_id` bigint NOT NULL COMMENT '考察学院id',
                                                        `inspect_college_name` varchar(64) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '考察学院名称',
                                                        `paper_type` varchar(64) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '试卷类型',
                                                        `question_name` varchar(64) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '大题名称',
                                                        `number_type` varchar(64) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '题号类型（客观题、主观题）',
                                                        `big_question_number` varchar(64) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '大题号',
                                                        `small_question_number` varchar(64) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '小题号(每一课程试卷的唯一标识)',
                                                        `question_type` varchar(64) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '题目类型',
                                                        `full_score` decimal(12,4) DEFAULT NULL COMMENT '满分',
                                                        `score_rules` varchar(32) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '计分规则',
                                                        `rules_desc` varchar(500) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '规则说明',
                                                        `knowledge_dimension` varchar(255) DEFAULT NULL COMMENT '知识维度',
                                                        `ability_dimension` varchar(255) DEFAULT NULL COMMENT '能力维度',
                                                        `literacy_dimension` varchar(255) DEFAULT NULL COMMENT '素养维度',
                                                        `standard_score_rate` decimal(12,4) DEFAULT NULL COMMENT '标准难度系数（得分率）',
                                                        `score_rate` decimal(12,4) DEFAULT NULL COMMENT '得分率',
                                                        `difficult` varchar(32) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '难度',
                                                        `paper_struct_judge` varchar(32) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '试卷结构每道题目正确（全对），错误枚举\\nALL_CORRECT("全对"), NOT_QUITE_RIGHT("不完全正确的"),',
                                                        PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 ROW_FORMAT=DYNAMIC COMMENT='教师考察学院下试卷结构维度分析表';

-- ----------------------------
-- Table structure for t_a_exam_course_college_teacher
-- ----------------------------
DROP TABLE IF EXISTS `t_a_exam_course_college_teacher`;
CREATE TABLE `t_a_exam_course_college_teacher` (
                                                   `id` bigint NOT NULL,
                                                   `exam_id` bigint NOT NULL COMMENT '考试id',
                                                   `school_id` bigint DEFAULT NULL,
                                                   `course_code` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '科目编码',
                                                   `course_name` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '科目名称',
                                                   `teacher_id` bigint NOT NULL COMMENT '授课教师id',
                                                   `inspect_college_id` bigint NOT NULL COMMENT '考察学院id（此表以该字段为统计）',
                                                   `inspect_college_name` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '考察学院名称（冗余）',
                                                   `teacher_name` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '授课教师名称（冗余）',
                                                   `avg_score` decimal(12,4) DEFAULT NULL COMMENT '卷面平均分',
                                                   `min_score_assign` decimal(12,4) DEFAULT NULL COMMENT '赋分后授课学生最低分',
                                                   `max_score_assign` decimal(12,4) DEFAULT NULL COMMENT '赋分后授课学生最高分',
                                                   `avg_score_assign` decimal(12,4) DEFAULT NULL COMMENT '赋分后授课学生平均分',
                                                   `upper_quartile` decimal(12,4) DEFAULT NULL COMMENT '授课学生分数上四分位数',
                                                   `median` decimal(12,4) DEFAULT NULL COMMENT '授课学生中位数',
                                                   `lower_quartile` decimal(12,4) DEFAULT NULL COMMENT '授课学生分数下四分位数',
                                                   `mode` varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '授课学生分数众数',
                                                   `standard_deviation` decimal(12,4) DEFAULT NULL COMMENT '授课学生分数标准差',
                                                   `relative_position` decimal(12,4) DEFAULT NULL COMMENT '授课学生分数相对位置',
                                                   `reality_count` int DEFAULT NULL COMMENT '授课学生实际参考人数',
                                                   `absent_count` int DEFAULT NULL COMMENT '授课学生缺考人数',
                                                   `total_count` int DEFAULT NULL COMMENT '总人数',
                                                   `teach_college_id` bigint DEFAULT NULL COMMENT '授课学院id',
                                                   `teach_college_name` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '授课学院名称',
                                                   `teacher_rank` int DEFAULT NULL COMMENT '该科目，学院下排名',
                                                   `teacher_count` int DEFAULT NULL COMMENT '教师人数',
                                                   `other_college_min_score_assign` decimal(12,4) DEFAULT NULL COMMENT '其他学院授课学生最低分（赋分）',
                                                   `other_college_max_score_assign` decimal(12,4) DEFAULT NULL COMMENT '其他学院授课学生最高分（赋分）',
                                                   `other_college_avg_score_assign` decimal(12,4) DEFAULT NULL COMMENT '其他学院授课学生平均分（赋分）',
                                                   `other_college_upper_quartile` decimal(12,4) DEFAULT NULL COMMENT '其他学院授课学生分数上四分位数',
                                                   `other_college_median` decimal(12,4) DEFAULT NULL COMMENT '其他学院授课学生中位数',
                                                   `other_college_lower_quartile` decimal(12,4) DEFAULT NULL COMMENT '其他学院授课学生分数下四分位数',
                                                   `other_college_mode` varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '其他学院授课学生分数众数',
                                                   `other_college_reality_count` int DEFAULT NULL COMMENT '其他学院授课学生实际参考人数',
                                                   `other_college_absent_count` int DEFAULT NULL COMMENT '其他学院授课学生缺考人数',
                                                   `other_college_total_count` int DEFAULT NULL COMMENT '其他学院总人数',
                                                   PRIMARY KEY (`id`) USING BTREE,
                                                   KEY `t_a_exam_course_college_teacher_idx` (`exam_id`,`course_code`,`teacher_name`,`inspect_college_id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 ROW_FORMAT=DYNAMIC COMMENT='参考课程学院下授课教师维度分析表（考试id、课程编号、考察学院id、教师id）';

-- ----------------------------
-- Table structure for t_a_exam_course_difficult
-- ----------------------------
DROP TABLE IF EXISTS `t_a_exam_course_difficult`;
CREATE TABLE `t_a_exam_course_difficult` (
                                             `id` bigint NOT NULL COMMENT 'id',
                                             `exam_id` bigint NOT NULL COMMENT '考试id',
                                             `school_id` bigint DEFAULT NULL,
                                             `course_code` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '科目编码',
                                             `course_name` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '科目名称',
                                             `paper_id` bigint DEFAULT NULL COMMENT '试卷id',
                                             `paper_type` varchar(64) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '试卷类型',
                                             `college_id` bigint NOT NULL COMMENT '学院id',
                                             `interpret` varchar(64) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '难度类型',
                                             `count` int DEFAULT NULL COMMENT '该难度题目数量',
                                             `scope` varchar(64) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '难度范围',
                                             `sch_avg_score_rate` decimal(12,4) DEFAULT NULL COMMENT '各难度题在全校的平均得分率',
                                             `col_avg_score_rate` decimal(12,4) DEFAULT NULL COMMENT '各难度题在学院的平均得分率',
                                             PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 ROW_FORMAT=DYNAMIC COMMENT='考试课程，各难度题目得分率表（难度题得分率、中等难度题得分率、简单题得分率）';

-- ----------------------------
-- Table structure for t_a_exam_course_dio
-- ----------------------------
DROP TABLE IF EXISTS `t_a_exam_course_dio`;
CREATE TABLE `t_a_exam_course_dio` (
                                       `id` bigint NOT NULL COMMENT 'id',
                                       `exam_id` bigint NOT NULL COMMENT '考试id',
                                       `school_Id` bigint DEFAULT NULL,
                                       `course_code` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '科目编码',
                                       `course_name` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '科目名称',
                                       `paper_id` bigint NOT NULL COMMENT '试卷id',
                                       `dimension_type` varchar(32) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '考察点类型',
                                       `dimension_code` varchar(32) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '考察点编号',
                                       `score_rate` decimal(12,4) DEFAULT NULL COMMENT '该考察点平均得分率',
                                       `total_score` decimal(12,4) DEFAULT NULL COMMENT '该考察点在试卷中的总分',
                                       `total_count` decimal(12,4) DEFAULT NULL COMMENT '该考察点考察的题目数量',
                                       PRIMARY KEY (`id`) USING BTREE,
                                       KEY `t_a_exam_course_dio_idx` (`exam_id`,`course_code`,`dimension_type`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 ROW_FORMAT=DYNAMIC COMMENT='参考课程试卷考察点（整体情况）维度表';

-- ----------------------------
-- Table structure for t_a_exam_course_record
-- ----------------------------
DROP TABLE IF EXISTS `t_a_exam_course_record`;
CREATE TABLE `t_a_exam_course_record` (
                                          `id` bigint NOT NULL,
                                          `school_id` bigint DEFAULT NULL,
                                          `exam_record_id` bigint NOT NULL COMMENT '基础考生成绩记录表id',
                                          `total_score` decimal(12,4) DEFAULT NULL COMMENT '卷面成绩（冗余）',
                                          `assigned_score` decimal(12,4) DEFAULT NULL COMMENT '赋分后成绩',
                                          `percent_grade` int DEFAULT NULL COMMENT '百分位等级',
                                          `score_level` varchar(16) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '得分水平 ABCDE',
                                          `col_rank` int DEFAULT NULL COMMENT '该学生成绩在学院中的排名（赋分）',
                                          `rank_level` varchar(16) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '该学生成绩排名所在的等级（col_rank）',
                                          `over_college_rate` decimal(12,4) DEFAULT NULL COMMENT '超过本院占比（赋分）',
                                          `standardized_coefficients` decimal(12,4) DEFAULT NULL COMMENT '标准回归系数',
                                          `exam_id` bigint DEFAULT NULL,
                                          `course_code` varchar(32) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL,
                                          `paper_id` bigint DEFAULT NULL COMMENT '试卷id（冗余）',
                                          `paper_type` varchar(16) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '试卷类型（冗余）',
                                          `student_id` bigint DEFAULT NULL,
                                          `student_code` varchar(64) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '学生编号',
                                          `teacher_id` bigint DEFAULT NULL,
                                          `clazz_id` bigint DEFAULT NULL,
                                          `teach_college_id` bigint DEFAULT NULL,
                                          `inspect_college_id` bigint DEFAULT NULL,
                                          `major_id` bigint DEFAULT NULL,
                                          `absent` tinyint DEFAULT NULL COMMENT '是否缺考 1缺考 0正常（冗余）',
                                          `student_current` tinyint DEFAULT NULL COMMENT '是否应届 1应届 0非应届（冗余）',
                                          PRIMARY KEY (`id`) USING BTREE,
                                          KEY `t_a_exam_course_record_idx` (`exam_id`,`course_code`,`exam_record_id`) USING BTREE,
                                          KEY `t_a_exam_course_record_exam_record_id_idx` (`exam_record_id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 ROW_FORMAT=DYNAMIC COMMENT='参考课程考生成绩维度表';

-- ----------------------------
-- Table structure for t_a_exam_course_record_dio
-- ----------------------------
DROP TABLE IF EXISTS `t_a_exam_course_record_dio`;
CREATE TABLE `t_a_exam_course_record_dio` (
                                              `id` bigint NOT NULL COMMENT 'id',
                                              `school_id` bigint DEFAULT NULL,
                                              `exam_record_id` bigint NOT NULL COMMENT '基础考生成绩记录表id',
                                              `paper_id` bigint NOT NULL COMMENT '试卷id',
                                              `exam_id` bigint DEFAULT NULL,
                                              `course_code` varchar(32) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL,
                                              `course_name` varchar(32) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL,
                                              `student_id` bigint DEFAULT NULL,
                                              `student_code` varchar(32) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL,
                                              `dimension_type` varchar(32) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '模块类型',
                                              `dimension_code` varchar(32) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '维度编号',
                                              `student_score` decimal(12,4) DEFAULT NULL COMMENT '该学生在该知识点的得分',
                                              `score_rate` decimal(12,4) DEFAULT NULL COMMENT '得分率',
                                              `proficiency` varchar(32) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '熟练度等级',
                                              `inspect_college_id` bigint DEFAULT NULL COMMENT '考察学院id',
                                              `inspect_college_name` varchar(32) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '考察学院名称',
                                              `teacher_id` bigint DEFAULT NULL,
                                              `teacher_name` varchar(32) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL,
                                              PRIMARY KEY (`id`) USING BTREE,
                                              KEY `mark_idx` (`school_id`,`exam_id`,`course_code`,`student_code`,`dimension_type`,`dimension_code`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 ROW_FORMAT=DYNAMIC COMMENT='参考课程考生各考察点维度分析表';

-- ----------------------------
-- Table structure for t_a_exam_course_record_mod
-- ----------------------------
DROP TABLE IF EXISTS `t_a_exam_course_record_mod`;
CREATE TABLE `t_a_exam_course_record_mod` (
                                              `id` bigint NOT NULL,
                                              `school_id` bigint DEFAULT NULL,
                                              `exam_record_id` bigint NOT NULL COMMENT '基础考生成绩表id',
                                              `paper_id` bigint NOT NULL COMMENT '试卷id',
                                              `exam_id` bigint DEFAULT NULL,
                                              `course_code` varchar(32) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL,
                                              `course_name` varchar(32) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL,
                                              `student_id` bigint DEFAULT NULL,
                                              `student_code` varchar(32) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL,
                                              `module_type` varchar(32) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '考察模块名称',
                                              `total_score` decimal(12,4) DEFAULT NULL COMMENT '该考生在该模块的总得分（实际分）',
                                              `score_rate` decimal(12,4) DEFAULT NULL COMMENT '该学生在该考察模块的整体掌握率（total_score/full_score）',
                                              `full_score` decimal(12,4) DEFAULT NULL COMMENT '考察模块在试卷中的总分(实际分)',
                                              `proficiency` varchar(32) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '该学生在该模块掌握的熟练度（score_rate）',
                                              `col_rank` int DEFAULT NULL COMMENT '该学生在该模块的得分在学院排名(赋分)',
                                              `percent_grade` int DEFAULT NULL COMMENT '百分等级数',
                                              `level` varchar(32) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '等级(不确定百分等级、排名等级、得分率等级)',
                                              `inspect_college_id` bigint DEFAULT NULL COMMENT '所属考察学院id',
                                              `inspect_college_name` varchar(32) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '学生所属考察学院名称',
                                              PRIMARY KEY (`id`) USING BTREE,
                                              KEY `t_a_exam_course_record_mod_idx` (`school_id`,`exam_id`,`student_code`,`course_code`,`module_type`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 ROW_FORMAT=DYNAMIC COMMENT='参考课程考生考察点模块维度表';

-- ----------------------------
-- Table structure for t_a_exam_course_teacher
-- ----------------------------
DROP TABLE IF EXISTS `t_a_exam_course_teacher`;
CREATE TABLE `t_a_exam_course_teacher` (
                                           `id` bigint NOT NULL COMMENT 'id',
                                           `exam_id` bigint NOT NULL COMMENT '考试id',
                                           `school_id` bigint DEFAULT NULL,
                                           `course_code` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '科目编码',
                                           `course_name` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '科目名称',
                                           `teacher_id` bigint NOT NULL COMMENT '教师id',
                                           `teacher_name` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '授课教师名称（冗余字段）',
                                           `min_score` decimal(12,4) DEFAULT NULL COMMENT '最低分',
                                           `max_score` decimal(12,4) DEFAULT NULL COMMENT '最高分',
                                           `avg_score` decimal(12,4) DEFAULT NULL COMMENT '平均分',
                                           `upper_quartile` decimal(12,4) DEFAULT NULL COMMENT '上四分位数',
                                           `median` decimal(12,4) DEFAULT NULL COMMENT '中位数',
                                           `lower_quartile` decimal(12,4) DEFAULT NULL COMMENT '下四分位数',
                                           `mode` varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '众数',
                                           `standard_deviation` decimal(12,4) DEFAULT NULL COMMENT '标准差',
                                           `relative_position` decimal(12,4) DEFAULT NULL COMMENT '相对位置',
                                           `reality_count` int DEFAULT NULL COMMENT '实际参考人数',
                                           `absent_count` int DEFAULT NULL COMMENT '缺考人数',
                                           `total_count` int DEFAULT NULL COMMENT '总人数',
                                           PRIMARY KEY (`id`) USING BTREE,
                                           KEY `t_a_exam_course_teacher_idx` (`exam_id`,`course_code`,`teacher_name`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 ROW_FORMAT=DYNAMIC COMMENT='参考课程授课教师维度表';

-- ----------------------------
-- Table structure for t_a_exam_course_teacher_college_difficult
-- ----------------------------
DROP TABLE IF EXISTS `t_a_exam_course_teacher_college_difficult`;
CREATE TABLE `t_a_exam_course_teacher_college_difficult` (
                                                             `id` bigint NOT NULL COMMENT '主键',
                                                             `exam_id` bigint NOT NULL COMMENT '考试id',
                                                             `school_id` bigint NOT NULL COMMENT '学校id',
                                                             `course_code` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '课程编号',
                                                             `course_name` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '课程名称',
                                                             `paper_id` bigint NOT NULL COMMENT '试卷id',
                                                             `paper_type` varchar(64) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '试卷类型',
                                                             `teacher_id` bigint NOT NULL COMMENT '教师id',
                                                             `teacher_name` varchar(64) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '教师名称',
                                                             `inspect_college_id` bigint NOT NULL COMMENT '考察学院id',
                                                             `inspect_college_name` varchar(64) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '考察学院名称',
                                                             `interpret` varchar(64) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '难度类型',
                                                             `count` int DEFAULT NULL COMMENT '该难度题目数量',
                                                             `scope` varchar(64) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '难度范围',
                                                             `col_avg_score_rate` decimal(12,4) DEFAULT NULL COMMENT '各难度题在考察学院集合的平均得分率',
                                                             `tea_col_avg_score_rate` decimal(12,4) DEFAULT NULL COMMENT '各难度题在教师考察学院下集合的平均得分率',
                                                             PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 ROW_FORMAT=DYNAMIC COMMENT='授课教师-本院难度分布和该教师在本院难度分布对比';

-- ----------------------------
-- Table structure for t_a_exam_course_teacher_college_dio
-- ----------------------------
DROP TABLE IF EXISTS `t_a_exam_course_teacher_college_dio`;
CREATE TABLE `t_a_exam_course_teacher_college_dio` (
                                                       `id` bigint NOT NULL,
                                                       `exam_id` bigint NOT NULL COMMENT '考试id',
                                                       `school_id` bigint NOT NULL COMMENT '学校id',
                                                       `course_code` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '课程编号',
                                                       `course_name` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '课程名称',
                                                       `teacher_id` bigint NOT NULL COMMENT '教师id',
                                                       `teacher_name` varchar(64) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '教师名称',
                                                       `inspect_college_id` bigint NOT NULL COMMENT '考察学院id',
                                                       `inspect_college_name` varchar(64) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '考察学院名称',
                                                       `dimension_type` varchar(64) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '考察点类型',
                                                       `dimension_code` varchar(64) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '考察点编号',
                                                       `avg_score` decimal(12,4) DEFAULT NULL COMMENT '考察点平均分',
                                                       `score_rate` decimal(12,4) DEFAULT NULL COMMENT '考察点得分率',
                                                       PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 ROW_FORMAT=DYNAMIC COMMENT='各个教师在考察学院下的各考察点得分情况表';

-- ----------------------------
-- Table structure for t_a_exam_course_teacher_college_paper_struct
-- ----------------------------
DROP TABLE IF EXISTS `t_a_exam_course_teacher_college_paper_struct`;
CREATE TABLE `t_a_exam_course_teacher_college_paper_struct` (
                                                                `id` bigint NOT NULL COMMENT '主键',
                                                                `school_id` bigint NOT NULL COMMENT '学校id',
                                                                `paper_struct_id` bigint NOT NULL COMMENT '试卷结构基础表id',
                                                                `exam_id` bigint NOT NULL COMMENT '考试id',
                                                                `course_code` varchar(32) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '课程编号',
                                                                `course_name` varchar(32) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '课程名称',
                                                                `paper_id` bigint NOT NULL COMMENT '试卷id',
                                                                `teacher_id` bigint NOT NULL COMMENT '教师id',
                                                                `teacher_name` varchar(64) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '教师名称',
                                                                `inspect_college_id` bigint NOT NULL COMMENT '考察学院id',
                                                                `inspect_college_name` varchar(64) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '考察学院名称',
                                                                `paper_type` varchar(64) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '试卷类型',
                                                                `question_name` varchar(64) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '大题名称',
                                                                `number_type` varchar(64) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '题号类型（客观题、主观题）',
                                                                `big_question_number` varchar(64) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '大题号',
                                                                `small_question_number` varchar(64) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '小题号(每一课程试卷的唯一标识)',
                                                                `question_type` varchar(64) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '题目类型',
                                                                `full_score` decimal(12,4) DEFAULT NULL COMMENT '满分',
                                                                `score_rules` varchar(32) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '计分规则',
                                                                `rules_desc` varchar(500) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '规则说明',
                                                                `knowledge_dimension` varchar(255) DEFAULT NULL COMMENT '知识维度',
                                                                `ability_dimension` varchar(255) DEFAULT NULL COMMENT '能力维度',
                                                                `literacy_dimension` varchar(255) DEFAULT NULL COMMENT '素养维度',
                                                                `standard_score_rate` decimal(12,4) DEFAULT NULL COMMENT '标准难度系数（得分率）',
                                                                `score_rate` decimal(12,4) DEFAULT NULL COMMENT '得分率',
                                                                `difficult` varchar(32) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '难度',
                                                                `paper_struct_judge` varchar(32) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '试卷结构每道题目正确（全对），错误枚举\\nALL_CORRECT("全对"), NOT_QUITE_RIGHT("不完全正确的"),',
                                                                PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 ROW_FORMAT=DYNAMIC COMMENT='教师考察学院下试卷结构维度分析表';

-- ----------------------------
-- Table structure for t_a_exam_course_teacher_difficult
-- ----------------------------
DROP TABLE IF EXISTS `t_a_exam_course_teacher_difficult`;
CREATE TABLE `t_a_exam_course_teacher_difficult` (
                                                     `id` bigint NOT NULL,
                                                     `exam_id` bigint NOT NULL COMMENT '考试id',
                                                     `school_id` bigint DEFAULT NULL,
                                                     `course_code` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL,
                                                     `course_name` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL,
                                                     `paper_id` bigint DEFAULT NULL,
                                                     `paper_type` varchar(64) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL,
                                                     `teacher_id` bigint NOT NULL,
                                                     `teacher_name` varchar(64) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL,
                                                     `interpret` varchar(64) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '难度类型',
                                                     `count` int DEFAULT NULL COMMENT '该难度题目数量',
                                                     `scope` varchar(64) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '难度范围',
                                                     `sch_avg_score_rate` decimal(12,4) DEFAULT NULL COMMENT '各难度题在全校的平均得分率',
                                                     `tea_avg_score_rate` decimal(12,4) DEFAULT NULL COMMENT '各难度题在教师的平均得分率',
                                                     PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 ROW_FORMAT=DYNAMIC COMMENT='授课教师-全校各难度得分率对比';

-- ----------------------------
-- Table structure for t_a_exam_course_teacher_dio
-- ----------------------------
DROP TABLE IF EXISTS `t_a_exam_course_teacher_dio`;
CREATE TABLE `t_a_exam_course_teacher_dio` (
                                               `id` bigint NOT NULL,
                                               `exam_id` bigint NOT NULL COMMENT '考试id',
                                               `school_id` bigint DEFAULT NULL COMMENT '学校id',
                                               `course_code` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '课程编号',
                                               `course_name` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '课程名称',
                                               `teacher_id` bigint DEFAULT NULL,
                                               `teacher_name` varchar(45) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '教师id',
                                               `dimension_type` varchar(32) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '模块类型',
                                               `dimension_code` varchar(32) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '考察点编号',
                                               `avg_score` decimal(12,4) DEFAULT NULL COMMENT '考察点教师授课学生平均得分',
                                               `score_rate` decimal(12,4) DEFAULT NULL COMMENT '该考察点教师平均得分率',
                                               PRIMARY KEY (`id`) USING BTREE,
                                               KEY `t_a_exam_course_teacher_dio_idx` (`exam_id`,`course_code`,`dimension_code`,`dimension_type`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 ROW_FORMAT=DYNAMIC COMMENT='教师维度分析表';

-- ----------------------------
-- Table structure for t_a_exam_course_teacher_paper_struct
-- ----------------------------
DROP TABLE IF EXISTS `t_a_exam_course_teacher_paper_struct`;
CREATE TABLE `t_a_exam_course_teacher_paper_struct` (
                                                        `id` bigint NOT NULL COMMENT '主键',
                                                        `school_id` bigint NOT NULL COMMENT '学校id',
                                                        `paper_struct_id` bigint NOT NULL COMMENT '试卷结构基础表id',
                                                        `exam_id` bigint NOT NULL COMMENT '考试id',
                                                        `course_code` varchar(32) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '课程编号',
                                                        `course_name` varchar(32) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '课程名称',
                                                        `paper_id` bigint NOT NULL COMMENT '试卷id',
                                                        `teacher_id` bigint NOT NULL COMMENT '教师id',
                                                        `teacher_name` varchar(64) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '教师名称',
                                                        `paper_type` varchar(64) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '试卷类型',
                                                        `question_name` varchar(64) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '大题名称',
                                                        `number_type` varchar(64) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '题号类型（客观题、主观题）',
                                                        `big_question_number` varchar(64) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '大题号',
                                                        `small_question_number` varchar(64) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '小题号(每一课程试卷的唯一标识)',
                                                        `question_type` varchar(64) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '题目类型',
                                                        `full_score` decimal(12,4) DEFAULT NULL COMMENT '满分',
                                                        `score_rules` varchar(32) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '计分规则',
                                                        `rules_desc` varchar(500) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '规则说明',
                                                        `knowledge_dimension` varchar(255) DEFAULT NULL COMMENT '知识维度',
                                                        `ability_dimension` varchar(255) DEFAULT NULL COMMENT '能力维度',
                                                        `literacy_dimension` varchar(255) DEFAULT NULL COMMENT '素养维度',
                                                        `standard_score_rate` decimal(12,4) DEFAULT NULL COMMENT '标准难度系数（得分率）',
                                                        `score_rate` decimal(12,4) DEFAULT NULL COMMENT '得分率',
                                                        `difficult` varchar(32) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '难度',
                                                        `paper_struct_judge` varchar(32) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '试卷结构每道题目正确（全对），错误枚举\\nALL_CORRECT("全对"), NOT_QUITE_RIGHT("不完全正确的"),',
                                                        PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 ROW_FORMAT=DYNAMIC COMMENT='教师下试卷结构维度分析表';

-- ----------------------------
-- Table structure for t_a_exam_total
-- ----------------------------
DROP TABLE IF EXISTS `t_a_exam_total`;
CREATE TABLE `t_a_exam_total` (
                                  `id` bigint NOT NULL,
                                  `exam_id` bigint NOT NULL COMMENT '基础考试表id',
                                  `school_id` bigint DEFAULT NULL,
                                  `college_count` int DEFAULT NULL COMMENT '考察学院总数',
                                  `college_names` text CHARACTER SET utf8 COLLATE utf8_general_ci COMMENT '考察学院名称（、隔开）',
                                  `course_count` int DEFAULT NULL COMMENT '课程总数',
                                  `public_course_count` int DEFAULT NULL COMMENT '公共课总数',
                                  `major_course_count` int DEFAULT NULL COMMENT '专业课总数',
                                  `total_count` int DEFAULT NULL COMMENT '总人数',
                                  `reality_count` int DEFAULT NULL COMMENT '实际参考人数',
                                  `absent_count` int DEFAULT NULL COMMENT '缺考人数',
                                  `total_course_times` int DEFAULT NULL COMMENT '总考试科次',
                                  `reality_course_times` int DEFAULT NULL COMMENT '实际考科次',
                                  `absent_course_times` int DEFAULT NULL COMMENT '缺考科次',
                                  `exam_time` bigint DEFAULT NULL COMMENT '考试时间',
                                  PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 ROW_FORMAT=DYNAMIC COMMENT='考试维度总计';

-- ----------------------------
-- Table structure for t_a_paper_struct
-- ----------------------------
DROP TABLE IF EXISTS `t_a_paper_struct`;
CREATE TABLE `t_a_paper_struct` (
                                    `id` bigint NOT NULL,
                                    `school_id` bigint DEFAULT NULL,
                                    `paper_struct_id` bigint NOT NULL COMMENT '基础试卷结构表id',
                                    `exam_id` bigint DEFAULT NULL COMMENT '考试id',
                                    `course_code` varchar(32) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '课程编号',
                                    `course_name` varchar(32) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '课程名称',
                                    `paper_id` bigint DEFAULT NULL COMMENT '基础试卷表id（冗余）',
                                    `paper_type` varchar(32) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '试卷类型',
                                    `question_name` varchar(200) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '大题名称',
                                    `number_type` varchar(32) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '题号类型（客观题、主观题）',
                                    `big_question_number` varchar(64) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '大题号',
                                    `small_question_number` varchar(64) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '小题号(每一课程试卷的唯一标识)',
                                    `question_type` varchar(32) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '题目类型',
                                    `full_score` decimal(12,4) DEFAULT NULL COMMENT '满分',
                                    `score_rules` varchar(32) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '计分规则',
                                    `rules_desc` varchar(500) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '规则说明',
                                    `knowledge_dimension` varchar(255) DEFAULT NULL COMMENT '知识维度',
                                    `ability_dimension` varchar(255) DEFAULT NULL COMMENT '能力维度',
                                    `literacy_dimension` varchar(255) DEFAULT NULL COMMENT '素养维度',
                                    `standard_score_rate` decimal(12,4) DEFAULT NULL COMMENT '标准难度系数（得分率）',
                                    `score_rate` decimal(12,4) DEFAULT NULL COMMENT '得分率',
                                    `difficult` varchar(32) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '难度',
                                    `validity` decimal(12,4) DEFAULT NULL COMMENT '效度',
                                    `paper_struct_judge` varchar(32) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '试卷结构每道题目正确（全对），错误枚举\nALL_CORRECT("全对"), NOT_QUITE_RIGHT("不完全正确的"),',
                                    PRIMARY KEY (`id`) USING BTREE,
                                    KEY `t_a_paper_struct_idx` (`exam_id`,`course_code`,`paper_struct_id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 ROW_FORMAT=DYNAMIC COMMENT='试卷结构维度分析表';

-- ----------------------------
-- Table structure for t_b_answer
-- ----------------------------
DROP TABLE IF EXISTS `t_b_answer`;
CREATE TABLE `t_b_answer` (
                              `id` bigint NOT NULL COMMENT '考生作答记录详情id',
                              `exam_record_id` bigint NOT NULL COMMENT '考试记录id',
                              `number_type` varchar(32) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '题号类型（客观题、主观题）',
                              `main_number` varchar(32) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '大题号',
                              `sub_number` varchar(32) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '小题号',
                              `answer` varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '考生作答答案',
                              `score` decimal(12,4) DEFAULT NULL COMMENT '分数',
                              `path` varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '作答轨迹',
                              `time` bigint DEFAULT NULL COMMENT '作答时间',
                              PRIMARY KEY (`id`) USING BTREE,
                              KEY `t_b_answer_idx` (`exam_record_id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 ROW_FORMAT=DYNAMIC COMMENT='基础考生作答记录详情表';

-- ----------------------------
-- Table structure for t_b_cloud_exam
-- ----------------------------
DROP TABLE IF EXISTS `t_b_cloud_exam`;
CREATE TABLE `t_b_cloud_exam` (
                                  `id` bigint NOT NULL COMMENT '对应云阅卷主键',
                                  `exam_id` bigint NOT NULL COMMENT '教研分析考试id',
                                  `school_id` bigint NOT NULL COMMENT '学校id',
                                  `enable` tinyint NOT NULL DEFAULT '1' COMMENT '是否启用，false：停用，true：启用',
                                  `remark` varchar(64) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '备注（记录云阅卷该考试下包含的学科名称）',
                                  `access_key` varchar(64) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '密钥key',
                                  `access_secret` varchar(64) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '密钥secret',
                                  `create_id` bigint DEFAULT NULL COMMENT '创建人id',
                                  `create_time` bigint DEFAULT NULL COMMENT '创建人名称',
                                  `update_id` bigint DEFAULT NULL COMMENT '更新人id',
                                  `update_time` bigint DEFAULT NULL COMMENT '更新人名称',
                                  PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 ROW_FORMAT=DYNAMIC COMMENT='云阅卷考试信息表（同步考生成绩使用）';

-- ----------------------------
-- Table structure for t_b_common_level_config
-- ----------------------------
DROP TABLE IF EXISTS `t_b_common_level_config`;
CREATE TABLE `t_b_common_level_config` (
                                           `id` bigint NOT NULL COMMENT '常规等级配置表主键',
                                           `exam_id` bigint NOT NULL,
                                           `course_code` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '科目编码',
                                           `course_name` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '科目名称',
                                           `level_type` varchar(32) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '等级类型（熟练度、百分等级、题目难度）',
                                           `level` varchar(32) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '等级',
                                           `scope` varchar(32) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '取值范围（计算用）',
                                           `interpret` varchar(32) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '描述',
                                           `min` decimal(12,4) DEFAULT NULL COMMENT '最小边界（展示用）',
                                           `max` decimal(12,4) DEFAULT NULL COMMENT '最大边界（展示用）',
                                           PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 ROW_FORMAT=DYNAMIC COMMENT='等级配置表（试卷难易度、成绩在学院排名百分比）';

-- ----------------------------
-- Table structure for t_b_common_rank_level_config
-- ----------------------------
DROP TABLE IF EXISTS `t_b_common_rank_level_config`;
CREATE TABLE `t_b_common_rank_level_config` (
                                                `id` bigint NOT NULL,
                                                `exam_id` bigint NOT NULL,
                                                `course_code` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '科目编码',
                                                `course_name` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '科目名称',
                                                `level` varchar(32) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '等级',
                                                `min` decimal(12,4) DEFAULT NULL COMMENT '展示用最小值',
                                                `max` decimal(12,4) DEFAULT NULL COMMENT '展示用最大值',
                                                `scope` varchar(32) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '取值范围（计算用）',
                                                `interpret` varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '解释',
                                                PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 ROW_FORMAT=DYNAMIC COMMENT='学生成绩在学院排名的配置表（赋分成绩在学院排名档次）';

-- ----------------------------
-- Table structure for t_b_dimension
-- ----------------------------
DROP TABLE IF EXISTS `t_b_dimension`;
CREATE TABLE `t_b_dimension` (
                                 `id` bigint NOT NULL,
                                 `exam_id` bigint DEFAULT NULL COMMENT '考试id',
                                 `course_code` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '科目编码',
                                 `course_name` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '科目名称',
                                 `dimension_type` varchar(32) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '维度类型 - 知识，能力，素养',
                                 `code_primary` varchar(32) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '一级维度编号',
                                 `name_primary` varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '一级维度名称',
                                 `code_second` varchar(32) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '二级维度编号',
                                 `name_second` varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '二级维度名称',
                                 `interpretation` varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '一级维度术语解释',
                                 PRIMARY KEY (`id`) USING BTREE,
                                 KEY `t_b_dimension_idx` (`exam_id`,`course_code`,`dimension_type`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 ROW_FORMAT=DYNAMIC COMMENT='考察点维度基础表';

-- ----------------------------
-- Table structure for t_b_exam
-- ----------------------------
DROP TABLE IF EXISTS `t_b_exam`;
CREATE TABLE `t_b_exam` (
                            `id` bigint NOT NULL COMMENT '教研分析考试主键',
                            `school_id` bigint NOT NULL COMMENT '学校id',
                            `exam_code` varchar(32) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '考试编号（在学校下唯一）',
                            `exam_name` varchar(32) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '考试名称（2020~2021学年上学期期末考试）',
                            `semester_id` bigint NOT NULL COMMENT '学期id',
                            `exam_time` bigint DEFAULT NULL COMMENT '考试时间',
                            `create_id` bigint DEFAULT NULL,
                            `create_time` bigint DEFAULT NULL,
                            `update_id` bigint DEFAULT NULL,
                            `update_time` bigint DEFAULT NULL,
                            PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 ROW_FORMAT=DYNAMIC COMMENT='教研分析基础考试信息表';

-- ----------------------------
-- Table structure for t_b_exam_course
-- ----------------------------
DROP TABLE IF EXISTS `t_b_exam_course`;
CREATE TABLE `t_b_exam_course` (
                                   `id` bigint NOT NULL COMMENT '主键',
                                   `school_id` bigint DEFAULT NULL COMMENT '学校id',
                                   `exam_id` bigint NOT NULL COMMENT '考试id',
                                   `course_code` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '科目编码',
                                   `course_name` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '科目名称',
                                   `teach_college_id` bigint DEFAULT NULL COMMENT '开课学院id',
                                   `teach_college_name` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '开课学院名称',
                                   `test_status` varchar(30) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '测试状态（UN_TEST：未测试、TEST：已测试、CHECKED：已抽检）',
                                   `publish_status` varchar(30) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '发布状态（UN_COMPUTE：未计算、COMPUTING：计算中、 UN_PUBLISH：未发布、PUBLISH：已发布）',
                                   `open_data_md5` mediumtext COMMENT '开放接口获取的数据md5记录',
                                   `create_id` bigint DEFAULT NULL COMMENT '创建人',
                                   `create_time` bigint DEFAULT NULL COMMENT '创建时间',
                                   `update_id` bigint DEFAULT NULL COMMENT '更新人',
                                   `update_time` bigint DEFAULT NULL COMMENT '更新时间',
                                   `paper_type` varchar(100) NOT NULL COMMENT '试卷编号',
                                   PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 ROW_FORMAT=DYNAMIC COMMENT='考试科目表';

-- ----------------------------
-- Table structure for t_b_exam_record
-- ----------------------------
DROP TABLE IF EXISTS `t_b_exam_record`;
CREATE TABLE `t_b_exam_record` (
                                   `id` bigint NOT NULL,
                                   `exam_id` bigint NOT NULL COMMENT '考试id',
                                   `paper_id` bigint NOT NULL COMMENT '试卷id',
                                   `paper_type` varchar(32) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '试卷类型',
                                   `exam_student_id` bigint NOT NULL COMMENT '考生id',
                                   `subjective_score` decimal(12,4) DEFAULT NULL COMMENT '主观题总分',
                                   `objective_score` decimal(12,4) DEFAULT NULL COMMENT '客观题总分',
                                   `total_score` decimal(12,4) DEFAULT NULL COMMENT '总分',
                                   PRIMARY KEY (`id`) USING BTREE,
                                   KEY `t_b_exam_record_idx` (`exam_student_id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 ROW_FORMAT=DYNAMIC COMMENT='考生考试记录';

-- ----------------------------
-- Table structure for t_b_exam_student
-- ----------------------------
DROP TABLE IF EXISTS `t_b_exam_student`;
CREATE TABLE `t_b_exam_student` (
                                    `id` bigint NOT NULL COMMENT '主键',
                                    `school_id` bigint DEFAULT NULL COMMENT '学校id',
                                    `exam_id` bigint NOT NULL COMMENT '考试id',
                                    `name` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '姓名',
                                    `student_id` bigint NOT NULL COMMENT '学生id',
                                    `course_code` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '科目编码',
                                    `course_name` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '科目名称',
                                    `teach_college_id` bigint NOT NULL COMMENT '开课学院id',
                                    `inspect_college_id` bigint NOT NULL COMMENT '考查学院id',
                                    `clazz_id` bigint NOT NULL COMMENT '考试时候的班级id',
                                    `major_id` bigint DEFAULT NULL COMMENT '考试时候所在的专业id',
                                    `teacher_id` bigint NOT NULL COMMENT '授课老师id',
                                    `ticket_number` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '准考证号',
                                    `student_code` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '学号',
                                    `absent` tinyint NOT NULL DEFAULT '0' COMMENT '是否缺考，false：没缺考，true：缺考',
                                    `student_current` tinyint NOT NULL DEFAULT '1' COMMENT '是否本届，false：非本届，true：本届',
                                    PRIMARY KEY (`id`) USING BTREE,
                                    KEY `t_b_exam_student_idx` (`exam_id`,`student_code`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 ROW_FORMAT=DYNAMIC COMMENT='考生表';

-- ----------------------------
-- Table structure for t_b_examination
-- ----------------------------
DROP TABLE IF EXISTS `t_b_examination`;
CREATE TABLE `t_b_examination` (
                                   `id` bigint NOT NULL,
                                   `school_id` bigint NOT NULL,
                                   `exam_id` bigint NOT NULL,
                                   `course_header_code` varchar(64) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '教务课头号',
                                   `examination_course_code` varchar(64) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '教务课程号',
                                   `course_name` varchar(64) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '课程名称',
                                   `teacher_code` varchar(45) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '教师编号',
                                   `teacher_name` varchar(64) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '教师名称',
                                   `teach_college_name` varchar(64) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '开课学院名称',
                                   `credit` varchar(64) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '学分',
                                   `student_code` varchar(64) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '学号',
                                   `student_name` varchar(64) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '学生名称',
                                   `inspect_college_name` varchar(64) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '考察学院名称',
                                   `major` varchar(64) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '专业',
                                   `study_type` varchar(64) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '学习类型（应届、本届）',
                                   `grade` varchar(64) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '年级',
                                   PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 ROW_FORMAT=DYNAMIC COMMENT='考务数据基础表';

-- ----------------------------
-- Table structure for t_b_examination_relation
-- ----------------------------
DROP TABLE IF EXISTS `t_b_examination_relation`;
CREATE TABLE `t_b_examination_relation` (
                                            `id` bigint NOT NULL,
                                            `school_id` bigint NOT NULL COMMENT '学校id',
                                            `exam_id` bigint NOT NULL COMMENT '考试id',
                                            `examination_course_code` varchar(64) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '考务数据课程编号',
                                            `course_name` varchar(64) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '课程名称',
                                            `teach_college_name` varchar(64) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '开课学院名称',
                                            `teacher_code` varchar(64) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '教师编号',
                                            `teacher_name` varchar(64) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '教师名称',
                                            PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 ROW_FORMAT=DYNAMIC COMMENT='考务关系表（学校-考试-课程-开课学院-教师）';

-- ----------------------------
-- Table structure for t_b_module_config
-- ----------------------------
DROP TABLE IF EXISTS `t_b_module_config`;
CREATE TABLE `t_b_module_config` (
                                     `id` bigint NOT NULL,
                                     `exam_id` bigint NOT NULL COMMENT '考试id',
                                     `course_code` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '科目编码',
                                     `course_name` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '科目名称',
                                     `module_type` varchar(64) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '模块类型（知识、维度、素养）',
                                     `formula` varchar(64) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '计算公式规则',
                                     `scope` varchar(64) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '取值范围（计算用）',
                                     `level_code` varchar(32) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '等级',
                                     `level_name` varchar(32) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '水平等级层次',
                                     `result` text CHARACTER SET utf8 COLLATE utf8_general_ci COMMENT '诊断结果',
                                     `advice` text CHARACTER SET utf8 COLLATE utf8_general_ci COMMENT '学习建议',
                                     `attribute` varchar(32) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '试卷结构表（t_b_paper_struct）中的模块属性列的列名称',
                                     PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 ROW_FORMAT=DYNAMIC COMMENT='考察点模块配置表';

-- ----------------------------
-- Table structure for t_b_module_proficiency
-- ----------------------------
DROP TABLE IF EXISTS `t_b_module_proficiency`;
CREATE TABLE `t_b_module_proficiency` (
                                          `id` bigint NOT NULL COMMENT '模块熟练度主键',
                                          `exam_id` bigint NOT NULL COMMENT '考试id',
                                          `course_code` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '科目编码',
                                          `course_name` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '科目名称',
                                          `module_type` varchar(32) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '模块类型',
                                          `interpret` varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '解释',
                                          `remark` varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '备注',
                                          `define` varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '二级熟练度定义',
                                          `level` varchar(32) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '等级',
                                          `min` varchar(32) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '展示用最小边界',
                                          `max` varchar(32) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '展示用最大边界',
                                          `scope` varchar(32) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '取值范围（计算用）',
                                          PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 ROW_FORMAT=DYNAMIC COMMENT='模块二级考察点维度熟练度配置，及模块简要描述表';

-- ----------------------------
-- Table structure for t_b_paper
-- ----------------------------
DROP TABLE IF EXISTS `t_b_paper`;
CREATE TABLE `t_b_paper` (
                             `id` bigint NOT NULL COMMENT '试卷id',
                             `exam_id` bigint NOT NULL COMMENT '考试id',
                             `course_code` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '科目编码',
                             `course_name` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '科目名称',
                             `paper_type` varchar(32) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '试卷类型',
                             `start_time` bigint DEFAULT NULL COMMENT '该试卷考试开始时间',
                             `end_time` bigint DEFAULT NULL COMMENT '该试卷考试结束时间',
                             `coefficient` decimal(12,4) DEFAULT NULL COMMENT '赋分系数（赋值分=卷面成绩 +（卷面满分-卷面成绩）/ 赋分系数）',
                             `total_score` decimal(12,4) DEFAULT NULL COMMENT '试卷满分',
                             `pass_score` decimal(12,4) DEFAULT NULL COMMENT '试卷及格分',
                             `score_type` varchar(64) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '赋分类型\\n1.NEED_ASSIGN_SCORE("是","需要且按照公式赋分")\\n2.NO_NEED_ASSIGN_SCORE("否","不需要赋分，标准分即为赋分")\\n3.SPECIAL_ASSIGN_SCORE("特殊赋分","特殊赋分，按照excel表进行赋分")',
                             PRIMARY KEY (`id`) USING BTREE,
                             KEY `t_b_paper_idx` (`exam_id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 ROW_FORMAT=DYNAMIC COMMENT='试卷基础信息表（赋分系数、试卷类型、满分、及格分等）';

-- ----------------------------
-- Table structure for t_b_paper_struct
-- ----------------------------
DROP TABLE IF EXISTS `t_b_paper_struct`;
CREATE TABLE `t_b_paper_struct` (
                                    `id` bigint NOT NULL,
                                    `paper_id` bigint DEFAULT NULL COMMENT '试卷基础表id',
                                    `question_name` varchar(200) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '大题名称',
                                    `number_type` varchar(32) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '题号类型（客观题、主观题）',
                                    `big_question_number` varchar(64) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '大题号',
                                    `small_question_number` varchar(64) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '小题号(每一课程试卷的唯一标识)',
                                    `question_type` varchar(32) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '题目类型',
                                    `full_score` decimal(12,4) DEFAULT NULL COMMENT '满分',
                                    `score_rules` varchar(32) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '计分规则',
                                    `rules_desc` varchar(500) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '规则说明',
                                    `knowledge_dimension` varchar(255) DEFAULT NULL COMMENT '知识维度',
                                    `ability_dimension` varchar(255) DEFAULT NULL COMMENT '能力维度',
                                    `literacy_dimension` varchar(255) DEFAULT NULL COMMENT '素养维度',
                                    PRIMARY KEY (`id`) USING BTREE,
                                    KEY `t_b_paper_struct_idx` (`paper_id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 ROW_FORMAT=DYNAMIC COMMENT='试卷结构表';

-- ----------------------------
-- Table structure for t_b_school_clazz
-- ----------------------------
DROP TABLE IF EXISTS `t_b_school_clazz`;
CREATE TABLE `t_b_school_clazz` (
                                    `id` bigint NOT NULL COMMENT '班级id',
                                    `school_id` bigint NOT NULL COMMENT '学校id',
                                    `clazz_code` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '班级编号',
                                    `clazz_name` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '班级名称',
                                    `enable` tinyint DEFAULT '1' COMMENT '是否启用，false：停用，true：启用',
                                    `create_id` bigint DEFAULT NULL,
                                    `create_time` bigint DEFAULT NULL,
                                    `update_id` bigint DEFAULT NULL,
                                    `update_time` bigint DEFAULT NULL,
                                    PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 ROW_FORMAT=DYNAMIC COMMENT='学校班级表';

-- ----------------------------
-- Table structure for t_b_school_major
-- ----------------------------
DROP TABLE IF EXISTS `t_b_school_major`;
CREATE TABLE `t_b_school_major` (
                                    `id` bigint NOT NULL,
                                    `school_id` bigint DEFAULT NULL COMMENT '学校id',
                                    `major_code` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '专业编号',
                                    `major_name` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '专业名称',
                                    `enable` tinyint DEFAULT '1' COMMENT '是否启用，false：停用，true：启用',
                                    `create_id` bigint DEFAULT NULL,
                                    `create_time` bigint DEFAULT NULL,
                                    `update_id` bigint DEFAULT NULL,
                                    `update_time` bigint DEFAULT NULL,
                                    PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 ROW_FORMAT=DYNAMIC COMMENT='学校专业表';

-- ----------------------------
-- Table structure for t_b_session
-- ----------------------------
DROP TABLE IF EXISTS `t_b_session`;
CREATE TABLE `t_b_session` (
                               `id` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '主键',
                               `identity` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '用户标识',
                               `type` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '用户类型',
                               `source` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '访问来源',
                               `platform` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '设备分类',
                               `device_id` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '设备标识',
                               `address` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '登录IP地址',
                               `access_token` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '访问令牌',
                               `last_access_time` bigint DEFAULT NULL COMMENT '最近访问时间',
                               `last_access_ip` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '最近访问IP地址',
                               `update_time` bigint DEFAULT NULL COMMENT '令牌更新时间',
                               `expire_time` bigint DEFAULT NULL COMMENT '令牌强制失效时间',
                               `app_source` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '应用来源',
                               `school_id` bigint DEFAULT NULL COMMENT '学校id',
                               `org_id` bigint DEFAULT NULL COMMENT '机构id',
                               PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 ROW_FORMAT=DYNAMIC COMMENT='会话表';

-- ----------------------------
-- Table structure for t_b_student
-- ----------------------------
DROP TABLE IF EXISTS `t_b_student`;
CREATE TABLE `t_b_student` (
                               `id` bigint NOT NULL,
                               `school_id` bigint NOT NULL COMMENT '学校id',
                               `name` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '姓名',
                               `student_code` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '学号(某学校学生的唯一标识)',
                               `gender` varchar(30) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '性别，MAN：男，WOMAN：女',
                               `person_img_url` varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '照片地址',
                               PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 ROW_FORMAT=DYNAMIC COMMENT='基础学生表';

-- ----------------------------
-- Table structure for t_b_sync_task
-- ----------------------------
DROP TABLE IF EXISTS `t_b_sync_task`;
CREATE TABLE `t_b_sync_task` (
                                 `id` bigint NOT NULL COMMENT '主键',
                                 `school_id` bigint DEFAULT NULL COMMENT '学校id',
                                 `org_id` bigint DEFAULT NULL COMMENT '机构id',
                                 `type` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '任务类型，CALCULATE：分析计算',
                                 `third_relate_id` bigint DEFAULT NULL COMMENT '第三方关联ID',
                                 `obj` varchar(500) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '实体信息',
                                 `progress` decimal(8,2) DEFAULT NULL COMMENT '进度',
                                 `status` varchar(30) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '任务状态，INIT：未开始，DATA_VALID：数据校验中，RUNNING：进行中，FINISH：已完成',
                                 `summary` text CHARACTER SET utf8 COLLATE utf8_general_ci COMMENT '实时摘要信息',
                                 `result` varchar(30) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '数据结果，SUCCESS：成功，ERROR：失败',
                                 `create_id` bigint DEFAULT NULL COMMENT '创建人',
                                 `create_time` bigint DEFAULT NULL COMMENT '创建时间',
                                 `update_id` bigint DEFAULT NULL COMMENT '修改人',
                                 `update_time` bigint DEFAULT NULL COMMENT '修改时间',
                                 `remark` varchar(500) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '备注',
                                 `reset_count` int DEFAULT '0' COMMENT '重试次数',
                                 `error_message` varchar(500) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '人工错误原因',
                                 `report_file_path` varchar(500) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '报告路径',
                                 `source` varchar(1000) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '原始数据',
                                 PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='同步任务表';

-- ----------------------------
-- Table structure for t_b_task
-- ----------------------------
DROP TABLE IF EXISTS `t_b_task`;
CREATE TABLE `t_b_task` (
                            `id` bigint NOT NULL COMMENT '主键',
                            `type` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '任务类型，QUESTION_MISSION_BATCH_CREATE：批量新建命题任务，\nSAMPLE_EXPORT：导出审核样本，\nEXAMINATION_IMPORT：考务数据导入，\nEXAMINATION_EXPORT：考务数据导出，\nPRINT_PDF_DOWNLOAD：批量下载pdf，\nCREATE_PDF：生成pdf',
                            `entity_id` bigint DEFAULT NULL COMMENT '关联业务对象id',
                            `status` varchar(30) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '任务状态，INIT：未开始，RUNNING：进行中，FINISH：已完成',
                            `summary` varchar(2000) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '实时摘要信息',
                            `progress` double DEFAULT NULL COMMENT '执行进度',
                            `result` varchar(30) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '数据结果，SUCCESS：成功，ERROR：失败',
                            `enable` tinyint NOT NULL DEFAULT '1' COMMENT '是否启用，false：停用，true：启用',
                            `import_file_name` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '导入文件名',
                            `import_file_path` varchar(500) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '导入文件路径',
                            `result_file_path` varchar(500) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '导出文件路径',
                            `report_file_path` varchar(500) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '报告路径',
                            `create_time` bigint DEFAULT NULL COMMENT '创建时间',
                            `create_id` bigint DEFAULT NULL COMMENT '创建人id',
                            `school_id` bigint DEFAULT NULL COMMENT '学校id',
                            `org_id` bigint DEFAULT NULL COMMENT '机构id',
                            `print_plan_id` bigint DEFAULT NULL COMMENT '印刷计划id',
                            `remark` mediumtext CHARACTER SET utf8 COLLATE utf8_general_ci COMMENT '备注',
                            `obj_name` varchar(500) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '实体名称',
                            `reset_count` int DEFAULT '0' COMMENT '重试次数',
                            `version` int DEFAULT '0' COMMENT '更新版本号',
                            `error_message` varchar(500) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '人工错误原因',
                            PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 ROW_FORMAT=DYNAMIC COMMENT='导入导出任务表';

-- ----------------------------
-- Table structure for t_b_teacher
-- ----------------------------
DROP TABLE IF EXISTS `t_b_teacher`;
CREATE TABLE `t_b_teacher` (
                               `id` bigint NOT NULL,
                               `school_id` bigint NOT NULL COMMENT '学校id',
                               `org_id` bigint DEFAULT NULL COMMENT '机构id',
                               `teacher_name` varchar(45) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '教师名称',
                               `teacher_code` varchar(45) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '教师编号（学校内唯一）',
                               `role_type` varchar(45) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '角色类型',
                               PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 ROW_FORMAT=DYNAMIC COMMENT='教师表';

-- ----------------------------
-- Table structure for t_g_error
-- ----------------------------
DROP TABLE IF EXISTS `t_g_error`;
CREATE TABLE `t_g_error` (
                             `id` bigint NOT NULL COMMENT '主键',
                             `obj_id` bigint DEFAULT NULL COMMENT '实体id',
                             `summary` mediumtext CHARACTER SET utf8 COLLATE utf8_general_ci COMMENT '实时摘要信息',
                             `create_time` bigint DEFAULT NULL COMMENT '创建时间',
                             PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 ROW_FORMAT=DYNAMIC COMMENT='全局异常错误信息表';

-- ----------------------------
-- Table structure for t_s_auth
-- ----------------------------
DROP TABLE IF EXISTS `t_s_auth`;
CREATE TABLE `t_s_auth` (
                            `id` bigint NOT NULL COMMENT '主键',
                            `school_id` bigint NOT NULL COMMENT '学校id',
                            `access_key` varchar(255) DEFAULT NULL COMMENT 'accessKey',
                            `access_secret` varchar(255) DEFAULT NULL COMMENT 'accessSecret',
                            `description` text COMMENT '离线授权证书',
                            `type` varchar(16) NOT NULL COMMENT '授权类型',
                            `create_id` bigint DEFAULT NULL COMMENT '创建人',
                            `create_time` bigint DEFAULT NULL COMMENT '创建时间',
                            `update_id` bigint DEFAULT NULL COMMENT '更新人',
                            `update_time` bigint DEFAULT NULL COMMENT '更新时间',
                            `expire_time` bigint DEFAULT NULL COMMENT '过期时间',
                            `file` mediumblob COMMENT '文件数据',
                            PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='激活授权配置表';